﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DependencyPropertiesDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private List<Presence> presences = new List<Presence>();
        private Boolean changed = false;
        public MainWindow()
        {
            InitializeComponent();
        }

        private void NewMenuItem_Click(object sender, RoutedEventArgs e)
        {
            presences.Clear();
            UpdateGUI();

        }

        private void UpdateGUI()
        {
            DataBox.Items.Clear();
            foreach(Presence presence in presences)
            {
                DataBox.Items.Add(presence);
            }
        }

        private void OpenMenuItem_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            if (dialog.ShowDialog() == true)
            {
                LoadData(dialog.FileName);
            }
        }

        private void LoadData(string FileName)
        {
            List<Presence> tmpPresences = new List<Presence>();
            using(StreamReader reader = new StreamReader(FileName))
            {
                string line;
                while((line=reader.ReadLine())!=null)
                {
                    try
                    {
                        tmpPresences.Add(new Presence(line));
                    }
                    catch(DataFormatException dfe)
                    {
                        MessageBox.Show("Error loading data: " + dfe.Message, "Error");
                    }
                }
            }
            presences = tmpPresences;
            UpdateGUI();
        }

        private void SaveMenuItem_Click(object sender, RoutedEventArgs e)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            if(dialog.ShowDialog() == true)
            {
                SaveData(dialog.FileName);
                changed = false;
            }
        }

        private void SaveData(string FileName)
        {
            using (StreamWriter writer = new StreamWriter(FileName))
            {
                foreach(Presence presence in presences)
                {
                    writer.WriteLine(presence.CSVFormat());
                }
            }
        }

        private void ExitMenuItem_Click(object sender, RoutedEventArgs e)
        {
            if (!changed)
            {
                Application.Current.Shutdown();
            }
            else
            {
                if(MessageBox.Show("Aktualni data nejsou ulozena. Prejete si je ulozit?", "Varovani",
                    MessageBoxButton.OKCancel) == MessageBoxResult.OK)
                {
                    SaveMenuItem_Click(sender, e);
                }
            }
        }

        private void AddMenuItem_Click(object sender, RoutedEventArgs e)
        {
            AddPresenceDialog dialog = new AddPresenceDialog();
            if(dialog.ShowDialog() == true)
            {
                presences.Add(dialog.presence);
                changed = true;
                UpdateGUI();
            }

        }
    }
}
